You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by an...@apache.org on 2015/05/13 15:29:40 UTC

[4/6] activemq-artemis git commit: Ensure all references to the project use ActiveMQ Artemis

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessage.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessage.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessage.java
index 47b4807..6d221e1 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessage.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessage.java
@@ -48,7 +48,7 @@ import org.apache.activemq.artemis.utils.UUID;
 
 
 /**
- * ActiveMQ implementation of a JMS Message.
+ * ActiveMQ Artemis implementation of a JMS Message.
  * <br>
  * JMS Messages only live on the client side - the server only deals with MessageImpl
  * instances
@@ -271,7 +271,7 @@ public class ActiveMQMessage implements javax.jms.Message
       else
       {
          // Some providers, like WSMQ do automatic conversions between native byte[] correlation id
-         // and String correlation id. This makes it impossible for ActiveMQ to guarantee to return the correct
+         // and String correlation id. This makes it impossible for ActiveMQ Artemis to guarantee to return the correct
          // type as set by the user
          // So we allow the behaviour to be overridden by a system property
          // https://jira.jboss.org/jira/browse/HORNETQ-356

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageConsumer.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageConsumer.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageConsumer.java
index 95e14a5..ba18375 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageConsumer.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageConsumer.java
@@ -34,7 +34,7 @@ import org.apache.activemq.artemis.api.core.client.MessageHandler;
 import org.apache.activemq.artemis.api.jms.ActiveMQJMSConstants;
 
 /**
- * ActiveMQ implementation of a JMS MessageConsumer.
+ * ActiveMQ Artemis implementation of a JMS MessageConsumer.
  */
 public final class ActiveMQMessageConsumer implements QueueReceiver, TopicSubscriber
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageProducer.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageProducer.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageProducer.java
index b4300e3..f6da663 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageProducer.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQMessageProducer.java
@@ -43,7 +43,7 @@ import org.apache.activemq.artemis.api.core.client.SendAcknowledgementHandler;
 import org.apache.activemq.artemis.utils.UUID;
 import org.apache.activemq.artemis.utils.UUIDGenerator;
 /**
- * ActiveMQ implementation of a JMS MessageProducer.
+ * ActiveMQ Artemis implementation of a JMS MessageProducer.
  */
 public class ActiveMQMessageProducer implements MessageProducer, QueueSender, TopicPublisher
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQObjectMessage.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQObjectMessage.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQObjectMessage.java
index 16547f6..c993a2a 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQObjectMessage.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQObjectMessage.java
@@ -32,7 +32,7 @@ import org.apache.activemq.artemis.api.core.client.ClientSession;
 import org.apache.activemq.artemis.utils.ObjectInputStreamWithClassLoader;
 
 /**
- * ActiveMQ implementation of a JMS ObjectMessage.
+ * ActiveMQ Artemis implementation of a JMS ObjectMessage.
  * <br>
  * Don't used ObjectMessage if you want good performance!
  * <p>

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueue.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueue.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueue.java
index 47f7a98..f958d79 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueue.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueue.java
@@ -21,7 +21,7 @@ import javax.jms.Queue;
 import org.apache.activemq.artemis.api.core.SimpleString;
 
 /**
- * ActiveMQ implementation of a JMS Queue.
+ * ActiveMQ Artemis implementation of a JMS Queue.
  * <br>
  * This class can be instantiated directly.
  */

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueueBrowser.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueueBrowser.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueueBrowser.java
index 2a518d3..20ee863 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueueBrowser.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQQueueBrowser.java
@@ -30,7 +30,7 @@ import org.apache.activemq.artemis.api.core.client.ClientMessage;
 import org.apache.activemq.artemis.api.core.client.ClientSession;
 
 /**
- * ActiveMQ implementation of a JMS QueueBrowser.
+ * ActiveMQ Artemis implementation of a JMS QueueBrowser.
  */
 public final class ActiveMQQueueBrowser implements QueueBrowser
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQSession.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQStreamMessage.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQStreamMessage.java
index d0a7345..3e573f3 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQStreamMessage.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQStreamMessage.java
@@ -42,7 +42,7 @@ import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadSho
 import static org.apache.activemq.artemis.reader.StreamMessageUtil.streamReadString;
 
 /**
- * ActiveMQ implementation of a JMS StreamMessage.
+ * ActiveMQ Artemis implementation of a JMS StreamMessage.
  */
 public final class ActiveMQStreamMessage extends ActiveMQMessage implements StreamMessage
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTemporaryQueue.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTemporaryQueue.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTemporaryQueue.java
index c06dd9a..cf22e88 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTemporaryQueue.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTemporaryQueue.java
@@ -20,7 +20,7 @@ import javax.jms.TemporaryQueue;
 
 
 /**
- * ActiveMQ implementation of a JMS TemporaryQueue.
+ * ActiveMQ Artemis implementation of a JMS TemporaryQueue.
  * <br>
  * This class can be instantiated directly.
  */

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTextMessage.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTextMessage.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTextMessage.java
index e1c857e..e9bdf14 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTextMessage.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTextMessage.java
@@ -30,7 +30,7 @@ import static org.apache.activemq.artemis.reader.TextMessageUtil.writeBodyText;
 
 
 /**
- * ActiveMQ implementation of a JMS TextMessage.
+ * ActiveMQ Artemis implementation of a JMS TextMessage.
  * <br>
  * This class was ported from SpyTextMessage in JBossMQ.
  */
@@ -61,7 +61,7 @@ public class ActiveMQTextMessage extends ActiveMQMessage implements TextMessage
    }
 
    /**
-    * A copy constructor for non-ActiveMQ JMS TextMessages.
+    * A copy constructor for non-ActiveMQ Artemis JMS TextMessages.
     */
    public ActiveMQTextMessage(final TextMessage foreign, final ClientSession session) throws JMSException
    {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTopic.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTopic.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTopic.java
index 9976b67..fda6782 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTopic.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQTopic.java
@@ -21,7 +21,7 @@ import javax.jms.Topic;
 import org.apache.activemq.artemis.api.core.SimpleString;
 
 /**
- * ActiveMQ implementation of a JMS Topic.
+ * ActiveMQ Artemis implementation of a JMS Topic.
  * <br>
  * This class can be instantiated directly.
  */

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQXAConnection.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQXAConnection.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQXAConnection.java
index 4e890a6..14e63ff 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQXAConnection.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQXAConnection.java
@@ -27,7 +27,7 @@ import javax.jms.XATopicSession;
 import org.apache.activemq.artemis.api.core.client.ClientSessionFactory;
 
 /**
- * ActiveMQ implementation of a JMS XAConnection.
+ * ActiveMQ Artemis implementation of a JMS XAConnection.
  * <p>
  * The flat implementation of {@link XATopicConnection} and {@link XAQueueConnection} is per design,
  * following common practices of JMS 1.1.

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/SelectorTranslator.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/SelectorTranslator.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/SelectorTranslator.java
index ebaf952..23b4bf6 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/SelectorTranslator.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/SelectorTranslator.java
@@ -21,12 +21,12 @@ import java.util.List;
 
 /**
  *
- * This class converts a JMS selector expression into a ActiveMQ core filter expression.
+ * This class converts a JMS selector expression into a ActiveMQ Artemis core filter expression.
  *
- * JMS selector and ActiveMQ filters use the same syntax but have different identifiers.
+ * JMS selector and ActiveMQ Artemis filters use the same syntax but have different identifiers.
  *
  * We basically just need to replace the JMS header and property Identifier names
- * with the corresponding ActiveMQ field and header Identifier names.
+ * with the corresponding ActiveMQ Artemis field and header Identifier names.
  *
  * We must be careful not to substitute any literals, or identifiers whose name contains the name
  * of one we want to substitute.

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jndi/ActiveMQInitialContextFactory.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jndi/ActiveMQInitialContextFactory.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jndi/ActiveMQInitialContextFactory.java
index dc6c85c..d83888a 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jndi/ActiveMQInitialContextFactory.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jndi/ActiveMQInitialContextFactory.java
@@ -31,7 +31,7 @@ import org.apache.activemq.artemis.api.jms.ActiveMQJMSClient;
 import org.apache.activemq.artemis.uri.ConnectionFactoryParser;
 
 /**
- * A factory of the ActiveMQ InitialContext which contains
+ * A factory of the ActiveMQ Artemis InitialContext which contains
  * {@link javax.jms.ConnectionFactory} instances as well as a child context called
  * <i>destinations</i> which contain all of the current active destinations, in
  * child context depending on the QoS such as transient or durable and queue or

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/QualityOfServiceMode.java
----------------------------------------------------------------------
diff --git a/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/QualityOfServiceMode.java b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/QualityOfServiceMode.java
index 0da768d..8979220 100644
--- a/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/QualityOfServiceMode.java
+++ b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/QualityOfServiceMode.java
@@ -42,7 +42,7 @@ package org.apache.activemq.artemis.jms.bridge;
  *
  * This QoS mode ensures messages will reach the destination from the source
  * once and only once. (Sometimes this mode is known as "exactly once"). If both
- * the source and the destination are on the same ActiveMQ server
+ * the source and the destination are on the same ActiveMQ Artemis server
  * instance then this can be achieved by sending and acknowledging the messages
  * in the same local transaction. If the source and destination are on different
  * servers this is achieved by enlisting the sending and consuming sessions in a

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/impl/JMSBridgeImpl.java
----------------------------------------------------------------------
diff --git a/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/impl/JMSBridgeImpl.java b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/impl/JMSBridgeImpl.java
index 2650a9b..c8d7e13 100644
--- a/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/impl/JMSBridgeImpl.java
+++ b/artemis-jms-server/src/main/java/org/apache/activemq/artemis/jms/bridge/impl/JMSBridgeImpl.java
@@ -1843,7 +1843,7 @@ public final class JMSBridgeImpl implements JMSBridge
 
             if (val instanceof byte[] == false)
             {
-               //Can't set byte[] array props through the JMS API - if we're bridging a ActiveMQ message it might have such props
+               //Can't set byte[] array props through the JMS API - if we're bridging a ActiveMQ Artemis message it might have such props
                msg.setObjectProperty(propName, entry.getValue());
             }
             else if (msg instanceof ActiveMQMessage)

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java
index 24a28a1..459d9d8 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ActiveMQProtonRemotingConnection.java
@@ -26,7 +26,7 @@ import org.apache.activemq.artemis.spi.core.remoting.Connection;
 import org.proton.plug.AMQPConnectionContext;
 
 /**
- * This is a Server's Connection representation used by ActiveMQ.
+ * This is a Server's Connection representation used by ActiveMQ Artemis.
  */
 public class ActiveMQProtonRemotingConnection extends AbstractRemotingConnection
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java
index ef40eeb..b992078 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/ProtonProtocolManager.java
@@ -41,7 +41,7 @@ import org.proton.plug.AMQPServerConnectionContext;
 import org.proton.plug.context.server.ProtonServerConnectionContextFactory;
 
 /**
- * A proton protocol manager, basically reads the Proton Input and maps proton resources to ActiveMQ resources
+ * A proton protocol manager, basically reads the Proton Input and maps proton resources to ActiveMQ Artemis resources
  */
 public class ProtonProtocolManager implements ProtocolManager<Interceptor>, NotificationListener
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java
index 11b5b13..9c1e3f5 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSMapMessage.java
@@ -34,7 +34,7 @@ import static org.apache.activemq.artemis.reader.MapMessageUtil.readBodyMap;
 import static org.apache.activemq.artemis.reader.MapMessageUtil.writeBodyMap;
 
 /**
- * ActiveMQ implementation of a JMS MapMessage.
+ * ActiveMQ Artemis implementation of a JMS MapMessage.
  */
 public final class ServerJMSMapMessage extends ServerJMSMessage implements MapMessage
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java
index 05aa81a..3cfc251 100644
--- a/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java
+++ b/artemis-protocols/artemis-amqp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/proton/converter/jms/ServerJMSTextMessage.java
@@ -28,7 +28,7 @@ import static org.apache.activemq.artemis.reader.TextMessageUtil.writeBodyText;
 
 
 /**
- * ActiveMQ implementation of a JMS TextMessage.
+ * ActiveMQ Artemis implementation of a JMS TextMessage.
  * <br>
  * This class was ported from SpyTextMessage in JBossMQ.
  */

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireMessageConverter.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/AbstractProtonContextSender.java b/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/AbstractProtonContextSender.java
index 9cd60a3..80f09ed 100644
--- a/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/AbstractProtonContextSender.java
+++ b/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/AbstractProtonContextSender.java
@@ -28,7 +28,7 @@ import org.proton.plug.util.CreditsSemaphore;
 import org.proton.plug.util.NettyWritable;
 
 /**
- * A this is a wrapper around a ActiveMQ ServerConsumer for handling outgoing messages and incoming acks via a Proton Sender
+ * A this is a wrapper around a ActiveMQ Artemis ServerConsumer for handling outgoing messages and incoming acks via a Proton Sender
  */
 public abstract class AbstractProtonContextSender extends ProtonInitializable implements ProtonDeliveryHandler
 {
@@ -79,7 +79,7 @@ public abstract class AbstractProtonContextSender extends ProtonInitializable im
 
    @Override
    /*
-   * handle an incoming Ack from Proton, basically pass to ActiveMQ to handle
+   * handle an incoming Ack from Proton, basically pass to ActiveMQ Artemis to handle
    * */
    public abstract void onMessage(Delivery delivery) throws ActiveMQAMQPException;
 

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/server/ProtonServerSenderContext.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/server/ProtonServerSenderContext.java b/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/server/ProtonServerSenderContext.java
index dbaf4b9..3a49c71 100644
--- a/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/server/ProtonServerSenderContext.java
+++ b/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/server/ProtonServerSenderContext.java
@@ -85,7 +85,7 @@ public class ProtonServerSenderContext extends AbstractProtonContextSender imple
    }
 
    /**
-    * create the actual underlying ActiveMQ Server Consumer
+    * create the actual underlying ActiveMQ Artemis Server Consumer
     */
    @Override
    public void initialise() throws Exception
@@ -252,7 +252,7 @@ public class ProtonServerSenderContext extends AbstractProtonContextSender imple
 
 
    /**
-    * handle an out going message from ActiveMQ, send via the Proton Sender
+    * handle an out going message from ActiveMQ Artemis, send via the Proton Sender
     */
    public int deliverMessage(Object message, int deliveryCount) throws Exception
    {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/util/ReusableLatch.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/util/ReusableLatch.java b/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/util/ReusableLatch.java
index 2a3fabe..8ba0bc3 100644
--- a/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/util/ReusableLatch.java
+++ b/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/util/ReusableLatch.java
@@ -27,7 +27,7 @@ import java.util.concurrent.locks.AbstractQueuedSynchronizer;
  * <p/>
  * <p>It could be used for sync points when one process is feeding the latch while another will wait when everything is done. (e.g. waiting IO completions to finish)</p>
  * <p/>
- * <p>On ActiveMQ we have the requirement of increment and decrement a counter until the user fires a ready handler (commit). At that point we just act as a regular countDown.</p>
+ * <p>On ActiveMQ Artemis we have the requirement of increment and decrement a counter until the user fires a ready handler (commit). At that point we just act as a regular countDown.</p>
  * <p/>
  * <p>Note: This latch is reusable. Once it reaches zero, you can call up again, and reuse it on further waits.</p>
  * <p/>

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompDecoder.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompDecoder.java b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompDecoder.java
index 3c4f744..93d2dbc 100644
--- a/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompDecoder.java
+++ b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompDecoder.java
@@ -371,7 +371,7 @@ public class StompDecoder
                   // trim off leading whitespace from header values.
                   // The STOMP spec examples seem to imply that whitespace should be trimmed although it is not
                   // explicit in the spec
-                  // ActiveMQ + StompConnect also seem to trim whitespace from header values.
+                  // ActiveMQ Artemis + StompConnect also seem to trim whitespace from header values.
                   // Trimming is problematic though if the user has set a header with a value which deliberately
                   // has
                   // leading whitespace since

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompFrameInterceptor.java
----------------------------------------------------------------------
diff --git a/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompFrameInterceptor.java b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompFrameInterceptor.java
index ee8755f..7c340c8 100644
--- a/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompFrameInterceptor.java
+++ b/artemis-protocols/artemis-stomp-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/stomp/StompFrameInterceptor.java
@@ -19,9 +19,9 @@ package org.apache.activemq.artemis.core.protocol.stomp;
 import org.apache.activemq.artemis.api.core.BaseInterceptor;
 
 /**
- * This class is a simple way to intercepting client calls on ActiveMQ using STOMP protocol.
+ * This class is a simple way to intercepting client calls on ActiveMQ Artemis using STOMP protocol.
  * <p>
- * To add an interceptor to ActiveMQ server, you have to modify the server configuration file
+ * To add an interceptor to ActiveMQ Artemis server, you have to modify the server configuration file
  * {@literal broker.xml}.<br>
  */
 public interface StompFrameInterceptor extends BaseInterceptor<StompFrame>

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAManagedConnectionFactory.java
----------------------------------------------------------------------
diff --git a/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAManagedConnectionFactory.java b/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAManagedConnectionFactory.java
index f722bfc..ec1151e 100644
--- a/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAManagedConnectionFactory.java
+++ b/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAManagedConnectionFactory.java
@@ -33,7 +33,7 @@ import org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory;
 import org.apache.activemq.artemis.service.extensions.xa.recovery.XARecoveryConfig;
 
 /**
- * ActiveMQ ManagedConnectionFactory
+ * ActiveMQ Artemis ManagedConnectionFactory
  */
 public final class ActiveMQRAManagedConnectionFactory implements ManagedConnectionFactory, ResourceAdapterAssociation
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAService.java
----------------------------------------------------------------------
diff --git a/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAService.java b/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAService.java
index 3c7f95f..b21eaea 100644
--- a/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAService.java
+++ b/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/ActiveMQRAService.java
@@ -24,7 +24,7 @@ import javax.management.ObjectName;
 
 
 /**
- * A ActiveMQRAService ensures that ActiveMQ Resource Adapter will be stopped *before* the ActiveMQ server.
+ * A ActiveMQRAService ensures that ActiveMQ Artemis Resource Adapter will be stopped *before* the ActiveMQ Artemis server.
  * https://jira.jboss.org/browse/HORNETQ-339
  */
 public class ActiveMQRAService

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/package.html
----------------------------------------------------------------------
diff --git a/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/package.html b/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/package.html
index 0960900..de1602c 100644
--- a/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/package.html
+++ b/artemis-ra/src/main/java/org/apache/activemq/artemis/ra/package.html
@@ -22,7 +22,7 @@
   </head>
 
   <body bgcolor="white">
-    <h1>ActiveMQ Resource Adaptor</h1>
+    <h1>ActiveMQ Artemis Resource Adaptor</h1>
 
   </body>
 </html>

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/ActiveMQ.java
----------------------------------------------------------------------
diff --git a/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/ActiveMQ.java b/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/ActiveMQ.java
index 514079f..adb742d 100644
--- a/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/ActiveMQ.java
+++ b/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/ActiveMQ.java
@@ -178,7 +178,7 @@ public class ActiveMQ
    }
 
    /**
-    * Was this ActiveMQ message generated from a REST call?
+    * Was this ActiveMQ Artemis message generated from a REST call?
     *
     * @param msg
     * @return

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/util/HttpMessageHelper.java
----------------------------------------------------------------------
diff --git a/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/util/HttpMessageHelper.java b/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/util/HttpMessageHelper.java
index d75ef18..879d654 100644
--- a/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/util/HttpMessageHelper.java
+++ b/artemis-rest/src/main/java/org/apache/activemq/artemis/rest/util/HttpMessageHelper.java
@@ -114,7 +114,7 @@ public class HttpMessageHelper
          }
          else
          {
-            // assume posted as a JMS or ActiveMQ object message
+            // assume posted as a JMS or ActiveMQ Artemis object message
             size = message.getBodyBuffer().readInt();
             byte[] body = new byte[size];
             message.getBodyBuffer().readBytes(body);

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-rest/src/main/resources/schema/artemis-rest.xsd
----------------------------------------------------------------------
diff --git a/artemis-rest/src/main/resources/schema/artemis-rest.xsd b/artemis-rest/src/main/resources/schema/artemis-rest.xsd
index de52b74..eebe777 100644
--- a/artemis-rest/src/main/resources/schema/artemis-rest.xsd
+++ b/artemis-rest/src/main/resources/schema/artemis-rest.xsd
@@ -24,8 +24,8 @@
                 <xsd:element name="server-in-vm-id" type="xsd:string" minOccurs="0" maxOccurs="1">
                     <xsd:annotation>
                         <xsd:documentation>
-                            The ActiveMQ REST implementation uses the IN-VM transport to communicate
-                            with ActiveMQ. It uses the default server id, which is "0".
+                            The ActiveMQ Artemis REST implementation uses the IN-VM transport to communicate
+                            with ActiveMQ Artemis. It uses the default server id, which is "0".
                         </xsd:documentation>
                     </xsd:annotation>
                 </xsd:element>
@@ -33,7 +33,7 @@
                     <xsd:annotation>
                         <xsd:documentation>
                             By default, all links (URLs) are published using custom headers.
-                            You can instead have the ActiveMQ REST implementation publish links
+                            You can instead have the ActiveMQ Artemis REST implementation publish links
                             using the Link Header specification instead if you desire.
                         </xsd:documentation>
                     </xsd:annotation>
@@ -73,7 +73,7 @@
                 <xsd:element name="producer-session-pool-size" type="xsd:int" minOccurs="0" maxOccurs="1">
                     <xsd:annotation>
                         <xsd:documentation>
-                            The REST implementation pools ActiveMQ sessions for sending messages.
+                            The REST implementation pools ActiveMQ Artemis sessions for sending messages.
                             This is the size of the pool. That number of sessions will be created
                             at startup time.
                         </xsd:documentation>
@@ -106,8 +106,8 @@
                 <xsd:element name="consumer-window-size" type="xsd:int" minOccurs="0" maxOccurs="1">
                     <xsd:annotation>
                         <xsd:documentation>
-                            For consumers, this config option is the same as the ActiveMQ one of the
-                            same name. It will be used by sessions created by the ActiveMQ REST
+                            For consumers, this config option is the same as the ActiveMQ Artemis one of the
+                            same name. It will be used by sessions created by the ActiveMQ Artemis REST
                             implementation.
                         </xsd:documentation>
                     </xsd:annotation>

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/config/Configuration.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/config/Configuration.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/config/Configuration.java
index 4accdb3..309c813 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/config/Configuration.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/config/Configuration.java
@@ -31,7 +31,7 @@ import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.core.settings.impl.ResourceLimitSettings;
 
 /**
- * A Configuration is used to configure ActiveMQ servers.
+ * A Configuration is used to configure ActiveMQ Artemis servers.
  */
 public interface Configuration
 {
@@ -187,7 +187,7 @@ public interface Configuration
    /**
     * Sets the domain used by JMX MBeans (provided JMX management is enabled).
     * <p/>
-    * Changing this JMX domain is required if multiple ActiveMQ servers are run inside
+    * Changing this JMX domain is required if multiple ActiveMQ Artemis servers are run inside
     * the same JVM and all servers are using the same MBeanServer.
     */
    Configuration setJMXDomain(String domain);
@@ -837,14 +837,14 @@ public interface Configuration
    boolean isMaskPassword();
 
    /*
-   * Whether or not that ActiveMQ should use all protocols available on the classpath. If false only the core protocol will
+   * Whether or not that ActiveMQ Artemis should use all protocols available on the classpath. If false only the core protocol will
    * be set, any other protocols will need to be set directly on the ActiveMQServer
    * */
    Configuration setResolveProtocols(boolean resolveProtocols);
 
    /*
    * @see #setResolveProtocols()
-   * @return whether ActiveMQ should resolve and use any Protocols available on the classpath
+   * @return whether ActiveMQ Artemis should resolve and use any Protocols available on the classpath
    * Default value is {@value org.apache.activemq.artemis.api.config.org.apache.activemq.artemis.api.config.ActiveMQDefaultConfiguration#DEFAULT_RESOLVE_PROTOCOLS}.
    * */
    boolean isResolveProtocols();

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/filter/impl/FilterImpl.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/filter/impl/FilterImpl.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/filter/impl/FilterImpl.java
index ccd0ee3..3632e4e 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/filter/impl/FilterImpl.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/filter/impl/FilterImpl.java
@@ -29,9 +29,9 @@ import org.apache.activemq.artemis.core.server.ActiveMQMessageBundle;
 import org.apache.activemq.artemis.core.server.ServerMessage;
 
 /**
-* This class implements a ActiveMQ filter
+* This class implements a ActiveMQ Artemis filter
 *
-* ActiveMQ filters have the same syntax as JMS 1.1 selectors, but the identifiers are different.
+* ActiveMQ Artemis filters have the same syntax as JMS 1.1 selectors, but the identifiers are different.
 *
 * Valid identifiers that can be used are:
 *

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/PagingStore.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/PagingStore.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/PagingStore.java
index 49949d5..bf18ffa 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/PagingStore.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/PagingStore.java
@@ -106,7 +106,7 @@ public interface PagingStore extends ActiveMQComponent
     * The file will still exist until Page.delete is called,
     * So, case the system is reloaded the same Page will be loaded back if delete is not called.
     *
-    * @throws Exception Note: This should still be part of the interface, even though ActiveMQ only uses through the
+    * @throws Exception Note: This should still be part of the interface, even though ActiveMQ Artemis only uses through the
     */
    Page depage() throws Exception;
 

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/impl/PagingStoreImpl.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/impl/PagingStoreImpl.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/impl/PagingStoreImpl.java
index d727701..f2ddcf6 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/impl/PagingStoreImpl.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/impl/PagingStoreImpl.java
@@ -663,7 +663,7 @@ public class PagingStoreImpl implements PagingStore
                   returnPage.delete(null);
 
                   // This will trigger this address to exit the page mode,
-                  // and this will make ActiveMQ start using the journal again
+                  // and this will make ActiveMQ Artemis start using the journal again
                   return null;
                }
                else

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/security/impl/SecurityStoreImpl.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/security/impl/SecurityStoreImpl.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/security/impl/SecurityStoreImpl.java
index cb55f1e..dad13e6 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/security/impl/SecurityStoreImpl.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/security/impl/SecurityStoreImpl.java
@@ -38,7 +38,7 @@ import org.apache.activemq.artemis.utils.ConcurrentHashSet;
 import org.apache.activemq.artemis.utils.TypedProperties;
 
 /**
- * The ActiveMQ SecurityStore implementation
+ * The ActiveMQ Artemis SecurityStore implementation
  */
 public class SecurityStoreImpl implements SecurityStore, HierarchicalRepositoryChangeListener
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServer.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServer.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServer.java
index bbc66b5..18a3ce1 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServer.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServer.java
@@ -49,7 +49,7 @@ import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManager;
 import org.apache.activemq.artemis.utils.ExecutorFactory;
 
 /**
- * This interface defines the internal interface of the ActiveMQ Server exposed to other components
+ * This interface defines the internal interface of the ActiveMQ Artemis Server exposed to other components
  * of the server.
  * <p>
  * This is not part of our public API.
@@ -91,7 +91,7 @@ public interface ActiveMQServer extends ActiveMQComponent
    NodeManager getNodeManager();
 
    /**
-    * Returns the resource to manage this ActiveMQ server.
+    * Returns the resource to manage this ActiveMQ Artemis server.
     * @throws IllegalStateException if the server is not properly started.
     */
    ActiveMQServerControlImpl getActiveMQServerControl();

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java
index e746022..57edd11 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/ActiveMQServerLogger.java
@@ -322,7 +322,7 @@ public interface ActiveMQServerLogger extends BasicLogger
    void divertBindingNotExists(SimpleString bindingName);
 
    @LogMessage(level = Logger.Level.WARN)
-   @Message(id = 222007, value = "Security risk! Apache ActiveMQ Artemis is running with the default cluster admin user and default password. Please see the cluster chapter in the ActiveMQ User Guide for instructions on how to change this.", format = Message.Format.MESSAGE_FORMAT)
+   @Message(id = 222007, value = "Security risk! Apache ActiveMQ Artemis is running with the default cluster admin user and default password. Please see the cluster chapter in the ActiveMQ Artemis User Guide for instructions on how to change this.", format = Message.Format.MESSAGE_FORMAT)
    void clusterSecurityRisk();
 
    @LogMessage(level = Logger.Level.WARN)

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/embedded/EmbeddedActiveMQ.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/embedded/EmbeddedActiveMQ.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/embedded/EmbeddedActiveMQ.java
index c2b22b0..311c25e 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/embedded/EmbeddedActiveMQ.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/embedded/EmbeddedActiveMQ.java
@@ -27,7 +27,7 @@ import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManager;
 import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManagerImpl;
 
 /**
- * Helper class to simplify bootstrap of ActiveMQ server.  Bootstraps from classpath-based config files.
+ * Helper class to simplify bootstrap of ActiveMQ Artemis server.  Bootstraps from classpath-based config files.
  */
 public class EmbeddedActiveMQ
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/AIOFileLockNodeManager.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/AIOFileLockNodeManager.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/AIOFileLockNodeManager.java
index b5bd927..a5e50fe 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/AIOFileLockNodeManager.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/AIOFileLockNodeManager.java
@@ -23,7 +23,7 @@ import java.nio.channels.FileLock;
 import org.apache.activemq.artemis.core.asyncio.impl.AsynchronousFileImpl;
 
 /**
- * This is using the ActiveMQ Libaio Native to perform calls to flock on a Linux system. At the
+ * This is using the ActiveMQ Artemis Libaio Native to perform calls to flock on a Linux system. At the
  * current version of RHEL there's a bug on GFS2 and because of that fctl is not functional what
  * will cause issues on Failover over Shared Storage.
  * <p/>

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ActiveMQServerImpl.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ActiveMQServerImpl.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ActiveMQServerImpl.java
index 7058168..ad743c7 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ActiveMQServerImpl.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ActiveMQServerImpl.java
@@ -134,7 +134,7 @@ import org.apache.activemq.artemis.utils.SecurityFormatter;
 import org.apache.activemq.artemis.utils.VersionLoader;
 
 /**
- * The ActiveMQ server implementation
+ * The ActiveMQ Artemis server implementation
  */
 public class ActiveMQServerImpl implements ActiveMQServer
 {
@@ -1651,7 +1651,7 @@ public class ActiveMQServerImpl implements ActiveMQServer
    }
 
    /**
-    * Sets up ActiveMQ Executor Services.
+    * Sets up ActiveMQ Artemis Executor Services.
     */
    private void initializeExecutorServices()
    {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ServiceRegistry.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ServiceRegistry.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ServiceRegistry.java
index dcb1137..85030b8 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ServiceRegistry.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/server/impl/ServiceRegistry.java
@@ -34,7 +34,7 @@ public class ServiceRegistry
 
    private ScheduledExecutorService scheduledExecutorService;
 
-   /* We are using a List rather than HashMap here as ActiveMQ allows multiple instances of the same class to be added
+   /* We are using a List rather than HashMap here as ActiveMQ Artemis allows multiple instances of the same class to be added
    * to the interceptor list
    */
    private Map<String, Interceptor> incomingInterceptors;

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/core/transaction/Transaction.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/core/transaction/Transaction.java b/artemis-server/src/main/java/org/apache/activemq/artemis/core/transaction/Transaction.java
index 38c43bf..abfb981 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/core/transaction/Transaction.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/core/transaction/Transaction.java
@@ -25,7 +25,7 @@ import org.apache.activemq.artemis.core.server.Queue;
 import org.apache.activemq.artemis.core.server.impl.RefsOperation;
 
 /**
- * A ActiveMQ internal transaction
+ * A ActiveMQ Artemis internal transaction
  */
 public interface Transaction
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/java/org/apache/activemq/artemis/spi/core/protocol/ProtocolManager.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/java/org/apache/activemq/artemis/spi/core/protocol/ProtocolManager.java b/artemis-server/src/main/java/org/apache/activemq/artemis/spi/core/protocol/ProtocolManager.java
index 989fb16..ecbe6e2 100644
--- a/artemis-server/src/main/java/org/apache/activemq/artemis/spi/core/protocol/ProtocolManager.java
+++ b/artemis-server/src/main/java/org/apache/activemq/artemis/spi/core/protocol/ProtocolManager.java
@@ -48,7 +48,7 @@ public interface ProtocolManager<P extends BaseInterceptor>
    boolean isProtocol(byte[] array);
 
    /**
-    * Gets the Message Converter towards ActiveMQ.
+    * Gets the Message Converter towards ActiveMQ Artemis.
     * Notice this being null means no need to convert
     *
     * @return

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/main/resources/schema/artemis-configuration.xsd
----------------------------------------------------------------------
diff --git a/artemis-server/src/main/resources/schema/artemis-configuration.xsd b/artemis-server/src/main/resources/schema/artemis-configuration.xsd
index 4f26c76..b86b0b1 100644
--- a/artemis-server/src/main/resources/schema/artemis-configuration.xsd
+++ b/artemis-server/src/main/resources/schema/artemis-configuration.xsd
@@ -38,7 +38,7 @@
                       minOccurs="0">
             <xsd:annotation>
                <xsd:documentation>
-                  If true then the ActiveMQ Server will make use of any Protocol Managers that are in available on the
+                  If true then the ActiveMQ Artemis Server will make use of any Protocol Managers that are in available on the
                   classpath. If false then only the core protocol will be available, unless in Embedded mode where users
                   can inject their own Protocol Managers.
                </xsd:documentation>
@@ -192,7 +192,7 @@
          <xsd:element name="jmx-domain" type="xsd:string" default="org.apache.activemq" maxOccurs="1" minOccurs="0">
             <xsd:annotation>
                <xsd:documentation>
-                  the JMX domain used to registered ActiveMQ MBeans in the MBeanServer
+                  the JMX domain used to registered ActiveMQ Artemis MBeans in the MBeanServer
                </xsd:documentation>
             </xsd:annotation>
          </xsd:element>

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-server/src/test/java/org/apache/activemq/artemis/core/filter/impl/FilterTest.java
----------------------------------------------------------------------
diff --git a/artemis-server/src/test/java/org/apache/activemq/artemis/core/filter/impl/FilterTest.java b/artemis-server/src/test/java/org/apache/activemq/artemis/core/filter/impl/FilterTest.java
index d94beee..92c032c 100644
--- a/artemis-server/src/test/java/org/apache/activemq/artemis/core/filter/impl/FilterTest.java
+++ b/artemis-server/src/test/java/org/apache/activemq/artemis/core/filter/impl/FilterTest.java
@@ -29,7 +29,7 @@ import org.junit.Before;
 import org.junit.Test;
 
 /**
- * Tests the compliance with the ActiveMQ Filter syntax.
+ * Tests the compliance with the ActiveMQ Artemis Filter syntax.
  */
 public class FilterTest extends SilentTestCase
 {

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/ActiveMQXAResourceWrapperImpl.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/ActiveMQXAResourceWrapperImpl.java b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/ActiveMQXAResourceWrapperImpl.java
index 92ac75a..bd7a66e 100644
--- a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/ActiveMQXAResourceWrapperImpl.java
+++ b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/ActiveMQXAResourceWrapperImpl.java
@@ -36,7 +36,7 @@ public class ActiveMQXAResourceWrapperImpl implements ActiveMQXAResourceWrapper
 
    /**
     * Creates a new XAResourceWrapper.  PRODUCT_NAME, productVersion and jndiName are useful for log output in the
-    * Transaction Manager.  For ActiveMQ only the resourceManagerID is required to allow Transaction Manager to recover
+    * Transaction Manager.  For ActiveMQ Artemis only the resourceManagerID is required to allow Transaction Manager to recover
     * from relevant recovery scenarios.
     *
     * @param xaResource

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java
index de1eef6..3f9b08c 100644
--- a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java
+++ b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java
@@ -34,13 +34,13 @@ import org.apache.activemq.artemis.api.core.TransportConfiguration;
  *                 value="org.apache.activemq.artemis.jms.server.recovery.ActiveMQXAResourceRecovery;org.apache.activemq.artemis.core.remoting.impl.invm.InVMConnectorFactory"/&gt;
  * </pre>
  * <p>
- * you'll need something like this if the ActiveMQ Server is remote
+ * you'll need something like this if the ActiveMQ Artemis Server is remote
  * <pre>
  *      &lt;property name="com.arjuna.ats.jta.recovery.XAResourceRecovery.ACTIVEMQ2"
  *                  value="org.apache.activemq.artemis.jms.server.recovery.ActiveMQXAResourceRecovery;org.apache.activemq.artemis.core.remoting.impl.netty.NettyConnectorFactory,guest,guest,host=localhost,port=61616"/&gt;
  * </pre>
  * <p>
- * you'll need something like this if the ActiveMQ Server is remote and has failover configured
+ * you'll need something like this if the ActiveMQ Artemis Server is remote and has failover configured
  * <pre>
  *             &lt;property name="com.arjuna.ats.jta.recovery.XAResourceRecovery.ACTIVEMQ2"
  *                       value="org.apache.activemq.artemis.jms.server.recovery.ActiveMQXAResourceRecovery;org.apache.activemq.artemis.core.remoting.impl.netty.NettyConnectorFactory,guest,guest,host=localhost,port=61616;org.apache.activemq.artemis.core.remoting.impl.netty.NettyConnectorFactory,guest,guest,host=localhost2,port=61617"/&gt;

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java
index 9ce285b..8bbeecc 100644
--- a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java
+++ b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java
@@ -37,7 +37,7 @@ import org.apache.activemq.artemis.api.core.client.SessionFailureListener;
  * Mainly from org.jboss.server.XAResourceWrapper from the JBoss AS server module
  *
  * The reason why we don't use that class directly is that it assumes on failure of connection
- * the RM_FAIL or RM_ERR is thrown, but in ActiveMQ we throw XA_RETRY since we want the recovery manager to be able
+ * the RM_FAIL or RM_ERR is thrown, but in ActiveMQ Artemis we throw XA_RETRY since we want the recovery manager to be able
  * to retry on failure without having to manually retry
  */
 public class ActiveMQXAResourceWrapper implements XAResource, SessionFailureListener

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/design-guide/en/clustering.md
----------------------------------------------------------------------
diff --git a/docs/design-guide/en/clustering.md b/docs/design-guide/en/clustering.md
index 235c0d9..d02bf09 100644
--- a/docs/design-guide/en/clustering.md
+++ b/docs/design-guide/en/clustering.md
@@ -20,4 +20,4 @@ Topology Discovery
 
 blah blah blah, topology etc
 
-![ActiveMQ topology-update.jpg](images/topology-update.jpg)
+![ActiveMQ Artemis topology-update.jpg](images/topology-update.jpg)

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/quickstart-guide/en/README.md
----------------------------------------------------------------------
diff --git a/docs/quickstart-guide/en/README.md b/docs/quickstart-guide/en/README.md
index d1b4e1f..e647459 100644
--- a/docs/quickstart-guide/en/README.md
+++ b/docs/quickstart-guide/en/README.md
@@ -1,4 +1,4 @@
-ActiveMQ Quick Start Manual
+ActiveMQ Artemis Quick Start Manual
 ====================
 
 How to get started with ActiveMQ
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/quickstart-guide/en/about.md
----------------------------------------------------------------------
diff --git a/docs/quickstart-guide/en/about.md b/docs/quickstart-guide/en/about.md
index 4d25f94..96eaedf 100644
--- a/docs/quickstart-guide/en/about.md
+++ b/docs/quickstart-guide/en/about.md
@@ -3,20 +3,20 @@ About ActiveMQ
 
 What is ActiveMQ?
 
--   ActiveMQ is an open source project to build a multi-protocol,
+-   ActiveMQ Artemis is an open source project to build a multi-protocol,
     embeddable, very high performance, clustered, asynchronous messaging
     system.
 
--   For answers to more questions about what ActiveMQ is and what it
+-   For answers to more questions about what ActiveMQ Artemis is and what it
     isn't please visit the [FAQs wiki
     page](http://www.jboss.org/community/wiki/ActiveMQGeneralFAQs).
 
 Why use ActiveMQ? Here are just a few of the reasons:
 
--   100% open source software. ActiveMQ is licenced using the Apache
+-   100% open source software. ActiveMQ Artemis is licenced using the Apache
     Software License v2.0 to minimise barriers to adoption.
 
--   ActiveMQ is designed with usability in mind.
+-   ActiveMQ Artemis is designed with usability in mind.
 
 -   Written in Java. Runs on any platform with a Java 6+ runtime, that's
     everything from Windows desktops to IBM mainframes.
@@ -30,7 +30,7 @@ Why use ActiveMQ? Here are just a few of the reasons:
     messaging system, and others you won't find anywhere else.
 
 -   Elegant, clean-cut design with minimal third party dependencies. Run
-    ActiveMQ stand-alone, run it in integrated in your favourite JEE
+    ActiveMQ Artemis stand-alone, run it in integrated in your favourite JEE
     application server, or run it embedded inside your own product. It's
     up to you.
 

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/quickstart-guide/en/download.md
----------------------------------------------------------------------
diff --git a/docs/quickstart-guide/en/download.md b/docs/quickstart-guide/en/download.md
index 7b3c08f..6004bf4 100644
--- a/docs/quickstart-guide/en/download.md
+++ b/docs/quickstart-guide/en/download.md
@@ -1,7 +1,7 @@
 Download
 ========
 
-The official ActiveMQ project page is <http://activemq.org/>.
+The official ActiveMQ Artemis project page is <http://activemq.org/>.
 
 Software Download
 =================
@@ -28,7 +28,7 @@ Project Information
 
 -   Follow us on [twitter](http://twitter.com/activemq)
 
--   ActiveMQ Git repository is <https://github.com/activemq/activemq>
+-   ActiveMQ Artemis Git repository is <https://github.com/activemq/activemq>
 
 -   All release tags are available from
     <https://github.com/activemq/activemq/tags>

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/quickstart-guide/en/examples.md
----------------------------------------------------------------------
diff --git a/docs/quickstart-guide/en/examples.md b/docs/quickstart-guide/en/examples.md
index 2844de9..f050a9c 100644
--- a/docs/quickstart-guide/en/examples.md
+++ b/docs/quickstart-guide/en/examples.md
@@ -44,7 +44,7 @@ Type the command `mvn verify` and you should see the following output:
     [INFO] Scanning for projects...
     [INFO]
     [INFO] ------------------------------------------------------------------------
-    [INFO] Building ActiveMQ JMS Queue Example 2.3.0.BETA-SNAPSHOT
+    [INFO] Building ActiveMQ Artemis JMS Queue Example 2.3.0.BETA-SNAPSHOT
     [INFO] ------------------------------------------------------------------------
     [INFO]
     [INFO] --- maven-resources-plugin:2.6:resources (default-resources) @ activemq-jms-queue-example ---
@@ -85,13 +85,13 @@ Type the command `mvn verify` and you should see the following output:
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.deployers.impl.FileConfigurationParser parseMainConfig
     WARN: AMQ222018: AIO was not located on this platform, it will fall back to using pure Java NIO. If your platform is Linux, install LibAIO to enable the AIO journal
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl start
-    INFO: AMQ221000: live server is starting with configuration ActiveMQ Configuration (clustered=false,backup=false,sharedStore=true,journalDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/journal,bindingsDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/bindings,largeMessagesDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/largemessages,pagingDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/paging)
+    INFO: AMQ221000: live server is starting with configuration ActiveMQ Artemis Configuration (clustered=false,backup=false,sharedStore=true,journalDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/journal,bindingsDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/bindings,largeMessagesDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/largemessages,pagingDirectory=/home/andy/projects/activemq-master/examples/jms/queue/target//server0/data/messaging/paging)
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl$SharedStoreLiveActivation run
     INFO: AMQ221006: Waiting to obtain live lock
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.persistence.impl.journal.JournalStorageManager <init>
     INFO: AMQ221013: Using NIO Journal
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl initialisePart1
-    WARN: AMQ222007: Security risk! ActiveMQ is running with the default cluster admin user and default password. Please see the ActiveMQ user guide, cluster chapter, for instructions on how to change this.
+    WARN: AMQ222007: Security risk! ActiveMQ Artemis is running with the default cluster admin user and default password. Please see the ActiveMQ Artemis user guide, cluster chapter, for instructions on how to change this.
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.FileLockNodeManager startLiveNode
     INFO: AMQ221034: Waiting to obtain live lock
     Apr 17, 2013 10:51:01 AM org.apache.activemq.core.server.impl.FileLockNodeManager startLiveNode
@@ -103,7 +103,7 @@ Type the command `mvn verify` and you should see the following output:
     Apr 17, 2013 10:51:02 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl$SharedStoreLiveActivation run
     INFO: AMQ221007: Server is now live
     Apr 17, 2013 10:51:02 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl start
-    INFO: AMQ221001: ActiveMQ Server version 2.3.0.SNAPSHOT (black'n'yellow, 123) [a57893ff-7783-11e2-9787-07ca142fc9f7]
+    INFO: AMQ221001: ActiveMQ Artemis Server version 2.3.0.SNAPSHOT (black'n'yellow, 123) [a57893ff-7783-11e2-9787-07ca142fc9f7]
     [INFO]
     [INFO] --- activemq-maven-plugin:1.1.1-SNAPSHOT:runClient (runClient) @ activemq-jms-queue-example ---
     Apr 17, 2013 10:51:02 AM org.apache.activemq.common.example.ActiveMQExample getContext
@@ -120,7 +120,7 @@ Type the command `mvn verify` and you should see the following output:
     Apr 17, 2013 10:51:03 AM org.apache.activemq.core.server.management.impl.ManagementServiceImpl stop
     WARN: AMQ222113: On ManagementService stop, there are 1 unexpected registered MBeans: [core.acceptor.netty-acceptor]
     Apr 17, 2013 10:51:03 AM org.apache.activemq.core.server.impl.ActiveMQServerImpl stop
-    INFO: AMQ221002: ActiveMQ Server version 2.3.0.SNAPSHOT (black'n'yellow, 123) [a57893ff-7783-11e2-9787-07ca142fc9f7] stopped
+    INFO: AMQ221002: ActiveMQ Artemis Server version 2.3.0.SNAPSHOT (black'n'yellow, 123) [a57893ff-7783-11e2-9787-07ca142fc9f7] stopped
     [INFO] ------------------------------------------------------------------------
     [INFO] BUILD SUCCESS
     [INFO] ------------------------------------------------------------------------
@@ -129,7 +129,7 @@ Type the command `mvn verify` and you should see the following output:
     [INFO] Final Memory: 11M/456M
     [INFO] ------------------------------------------------------------------------
 
-Congratulations! You have successfully run your first ActiveMQ example.
+Congratulations! You have successfully run your first ActiveMQ Artemis example.
 Try some of the others.
 
 The Java EE Examples
@@ -157,7 +157,7 @@ In the shell window you should see something like the following output:
     [INFO] Scanning for projects...
     [INFO]
     [INFO] ------------------------------------------------------------------------
-    [INFO] Building ActiveMQ JEE MDB Example 2.3.0.BETA-SNAPSHOT
+    [INFO] Building ActiveMQ Artemis JEE MDB Example 2.3.0.BETA-SNAPSHOT
     [INFO] ------------------------------------------------------------------------
     [INFO]
     [INFO] --- maven-resources-plugin:2.6:resources (default-resources) @ activemq-jee-mdb-bmt-example ---
@@ -220,7 +220,7 @@ In the shell window you should see something like the following output:
     10:58:05,831 INFO  [org.jboss.ws.common.management.AbstractServerConfig] (MSC service thread 1-4) JBoss Web Services - Stack CXF Server 4.0.2.GA
     10:58:05,943 INFO  [org.apache.coyote.http11.Http11Protocol] (MSC service thread 1-6) Starting Coyote HTTP/1.1 on http-localhost.localdomain-127.0.0.1-8080
     10:58:05,966 INFO  [org.jboss.as.jacorb] (MSC service thread 1-2) JBAS016330: CORBA ORB Service started
-    10:58:05,988 INFO  [org.apache.activemq.core.server.impl.ActiveMQServerImpl] (MSC service thread 1-11) live server is starting with configuration ActiveMQ Configuration (clustered=false,backup=false,sharedStore=true,journalDirectory=/home/andy/projects/activemq-master/examples/javaee/mdb-bmt/target/jbossas-node0/standalone/data/messagingjournal,bindingsDirectory=/home/andy/projects/activemq-master/examples/javaee/mdb-bmt/target/jbossas-node0/standalone/data/messagingbindings,largeMessagesDirectory=/home/andy/projects/activemq-master/examples/javaee/mdb-bmt/target/jbossas-node0/standalone/data/messaginglargemessages,pagingDirectory=/home/andy/projects/activemq-master/examples/javaee/mdb-bmt/target/jbossas-node0/standalone/data/messagingpaging)
+    10:58:05,988 INFO  [org.apache.activemq.core.server.impl.ActiveMQServerImpl] (MSC service thread 1-11) live server is starting with configuration ActiveMQ Artemis Configuration (clustered=false,backup=false,sharedStore=true,journalDirectory=/home/andy/projects/activemq-master/examples/javaee/mdb-bmt/target/jbossas-node0/standalone/data/messagingjournal,bindingsDirectory=/home/andy/projects/activemq-master/examples/javaee/mdb-bmt/target/jbossas-node0/standalone/data/messagingbindings,largeMessagesDirectory=/home/andy/projects/activemq-master/examples/javaee/mdb-bmt/target/jbossas-node0/standalone/data/messaginglargemessages,pagingDirectory=/home/andy/projects/activemq-master/examples/javaee/mdb-bmt/target/jbossas-node0/standalone/data/messagingpaging)
     10:58:05,996 INFO  [org.apache.activemq.core.server.impl.ActiveMQServerImpl] (MSC service thread 1-11) Waiting to obtain live lock
     10:58:06,037 INFO  [org.apache.activemq.core.persistence.impl.journal.JournalStorageManager] (MSC service thread 1-11) Using AIO Journal
     10:58:06,122 INFO  [org.jboss.as.jacorb] (MSC service thread 1-14) JBAS016328: CORBA Naming Service started
@@ -233,7 +233,7 @@ In the shell window you should see something like the following output:
     10:58:08,790 INFO  [org.apache.activemq.core.remoting.impl.netty.NettyAcceptor] (MSC service thread 1-11) Started Netty Acceptor version 3.2.5.Final-a96d88c localhost.localdomain:61616 for CORE protocol
     10:58:08,793 INFO  [org.apache.activemq.core.remoting.impl.netty.NettyAcceptor] (MSC service thread 1-11) Started Netty Acceptor version 3.2.5.Final-a96d88c localhost.localdomain:5455 for CORE protocol
     10:58:08,795 INFO  [org.apache.activemq.core.server.impl.ActiveMQServerImpl] (MSC service thread 1-11) Server is now live
-    10:58:08,797 INFO  [org.apache.activemq.core.server.impl.ActiveMQServerImpl] (MSC service thread 1-11) ActiveMQ Server version 2.2.13.Final (AMQ_2_2_13_FINAL_AS7, 122) [5c499e88-9c63-11e2-bfa3-fe5400591699]) started
+    10:58:08,797 INFO  [org.apache.activemq.core.server.impl.ActiveMQServerImpl] (MSC service thread 1-11) ActiveMQ Artemis Server version 2.2.13.Final (AMQ_2_2_13_FINAL_AS7, 122) [5c499e88-9c63-11e2-bfa3-fe5400591699]) started
     10:58:08,822 INFO  [org.jboss.as.messaging] (MSC service thread 1-4) JBAS011601: Bound messaging object to jndi name java:jboss/exported/jms/RemoteConnectionFactory
     10:58:08,824 INFO  [org.jboss.as.messaging] (MSC service thread 1-4) JBAS011601: Bound messaging object to jndi name java:/RemoteConnectionFactory
     10:58:08,825 INFO  [org.jboss.as.messaging] (MSC service thread 1-10) JBAS011601: Bound messaging object to jndi name java:/ConnectionFactory
@@ -241,7 +241,7 @@ In the shell window you should see something like the following output:
     10:58:08,836 INFO  [org.jboss.as.messaging] (MSC service thread 1-3) JBAS011601: Bound messaging object to jndi name java:/queue/test
     10:58:08,840 INFO  [org.jboss.as.messaging] (MSC service thread 1-3) JBAS011601: Bound messaging object to jndi name java:jboss/exported/jms/queues/testQueue
     10:58:08,859 INFO  [org.jboss.as.deployment.connector] (MSC service thread 1-9) JBAS010406: Registered connection factory java:/JmsXA
-    10:58:08,866 INFO  [org.apache.activemq.ra.ActiveMQResourceAdapter] (MSC service thread 1-9) ActiveMQ resource adaptor started
+    10:58:08,866 INFO  [org.apache.activemq.ra.ActiveMQResourceAdapter] (MSC service thread 1-9) ActiveMQ Artemis resource adaptor started
     10:58:08,867 INFO  [org.jboss.as.connector.services.ResourceAdapterActivatorService$ResourceAdapterActivator] (MSC service thread 1-9) IJ020002: Deployed: file://RaActivatoractivemq-ra
     10:58:08,870 INFO  [org.jboss.as.deployment.connector] (MSC service thread 1-5) JBAS010401: Bound JCA ConnectionFactory [java:/JmsXA]
     10:58:08,898 INFO  [org.jboss.as.server.deployment] (MSC service thread 1-10) JBAS015876: Starting deployment of "ONT001-1.0.war"

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/quickstart-guide/en/installation.md
----------------------------------------------------------------------
diff --git a/docs/quickstart-guide/en/installation.md b/docs/quickstart-guide/en/installation.md
index 7b3d8d5..86fa8b8 100644
--- a/docs/quickstart-guide/en/installation.md
+++ b/docs/quickstart-guide/en/installation.md
@@ -1,20 +1,20 @@
 Installation
 ============
 
-This section describes how to install ActiveMQ.
+This section describes how to install ActiveMQ Artemis.
 
 Prerequisites
 =============
 
 > **Note**
 >
-> ActiveMQ only runs on Java 7 or later.
+> ActiveMQ Artemis only runs on Java 7 or later.
 
-By default, ActiveMQ server runs with 1GiB of memory. If your computer
+By default, ActiveMQ Artemis server runs with 1GiB of memory. If your computer
 has less memory, or you want to run it with more available RAM, modify
 the value in `bin/run.sh` accordingly.
 
-For persistence, ActiveMQ uses its own fast journal, which you can
+For persistence, ActiveMQ Artemis uses its own fast journal, which you can
 configure to use libaio (which is the default when running on Linux) or
 Java NIO. In order to use the libaio module on Linux, you'll need to
 install libaio, if it's not already installed.
@@ -58,7 +58,7 @@ structure:
              |___ schemas
           
 
--   `bin` -- binaries and scripts needed to run ActiveMQ.
+-   `bin` -- binaries and scripts needed to run ActiveMQ Artemis.
 
 -   `docs` -- guides and javadocs for ActiveMQ
 
@@ -69,5 +69,5 @@ structure:
 
 -   `licenses` -- licenses for ActiveMQ
 
--   `schemas` -- XML Schemas used to validate ActiveMQ configuration
+-   `schemas` -- XML Schemas used to validate ActiveMQ Artemis configuration
     files

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/quickstart-guide/en/introduction.md
----------------------------------------------------------------------
diff --git a/docs/quickstart-guide/en/introduction.md b/docs/quickstart-guide/en/introduction.md
index 98f7a43..6014a21 100644
--- a/docs/quickstart-guide/en/introduction.md
+++ b/docs/quickstart-guide/en/introduction.md
@@ -2,10 +2,10 @@ Getting Started
 ===============
 
 This short guide explains how to download, install and quickly get
-started with ActiveMQ.
+started with ActiveMQ Artemis.
 
 After downloading and installing we highly recommend you run the
-examples to get acquainted with ActiveMQ. We ship with over 70 examples
+examples to get acquainted with ActiveMQ Artemis. We ship with over 70 examples
 demonstrating most of the features.
 
 This guide is not intended to be a replacement for the user manual. The

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/quickstart-guide/en/running.md
----------------------------------------------------------------------
diff --git a/docs/quickstart-guide/en/running.md b/docs/quickstart-guide/en/running.md
index 5bd483a..b760d5d 100644
--- a/docs/quickstart-guide/en/running.md
+++ b/docs/quickstart-guide/en/running.md
@@ -5,7 +5,7 @@ Creating a Broker Instance
 A broker instance is the directory containing all the configuration and runtime
 data, such as logs and data files, associated with a broker process.  It is recommended that
 you do *not* create the instance directory under `${ARTEMIS_HOME}`.  This separation is
-encouraged so that you can more easily upgrade when the next version of ActiveMQ is released.
+encouraged so that you can more easily upgrade when the next version of ActiveMQ Artemis is released.
 
 On Unix systems, it is a common convention to store this kind of runtime data under 
 the `/var/lib` directory.  For example, to create an instance at '/var/lib/mybroker', run

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/user-manual/en/README.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/README.md b/docs/user-manual/en/README.md
index 99d869c..1c01617 100644
--- a/docs/user-manual/en/README.md
+++ b/docs/user-manual/en/README.md
@@ -1,4 +1,4 @@
-![ActiveMQ logo](images/artemis-logo.jpg)
+![ActiveMQ Artemis logo](images/artemis-logo.jpg)
 
 Apache ActiveMQ Artemis User Manual
 ====================

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/user-manual/en/architecture.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/architecture.md b/docs/user-manual/en/architecture.md
index b20efec..b966f9c 100644
--- a/docs/user-manual/en/architecture.md
+++ b/docs/user-manual/en/architecture.md
@@ -57,7 +57,7 @@ The server always just deals with core API interactions.
 
 A schematic illustrating this relationship is shown in figure 3.1 below:
 
-![ActiveMQ architecture1](images/architecture1.jpg)
+![ActiveMQ Artemis architecture1](images/architecture1.jpg)
 
 Figure 3.1 shows two user applications interacting with an Apache ActiveMQ Artemis
 server. User Application 1 is using the JMS API, while User Application
@@ -119,7 +119,7 @@ talking directly to the Apache ActiveMQ Artemis server. This is not recommended
 you'll most likely end up creating a new connection and session every
 time you want to interact from the EJB, which is an anti-pattern.
 
-![ActiveMQ architecture2](images/architecture2.jpg)
+![ActiveMQ Artemis architecture2](images/architecture2.jpg)
 
 For more information on using the JCA adaptor, please see [Application Server Integration and Java EE](appserver-integration.md).
 
@@ -137,7 +137,7 @@ ConnectionFactory instances from any server side JMS
 configuration. It also provides a simple management API for
 creating and destroying Queues and Topics
 which can be accessed via JMX or the connection. It is a separate
-service to the ActiveMQ core server, since the core server is JMS
+service to the ActiveMQ Artemis core server, since the core server is JMS
 agnostic. If you don't want to deploy any JMS Queue or Topic via
 server side XML configuration and don't require a JMS management
 API on the server side then you can disable this service.
@@ -147,6 +147,6 @@ for bootstrapping the Broker.
 
 The stand-alone server architecture is shown in figure 3.3 below:
 
-![ActiveMQ architecture3](images/architecture3.jpg)
+![ActiveMQ Artemis architecture3](images/architecture3.jpg)
 
 For more information on server configuration files see [Server Configuration](configuration-index.md)

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/docs/user-manual/en/configuration-index.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/configuration-index.md b/docs/user-manual/en/configuration-index.md
index 2ffa93e..6de46ee 100644
--- a/docs/user-manual/en/configuration-index.md
+++ b/docs/user-manual/en/configuration-index.md
@@ -72,7 +72,7 @@ Name | Description
 [page-max-concurrent-io](paging.md "24.3. Paging Mode")                                               |  The max number of concurrent reads allowed on paging. Default=5
 [paging-directory](paging.md "24.2. Configuration")                                                   |  the directory to store paged messages in. Default=data/paging
 [persist-delivery-count-before-delivery](undelivered-messages.md "21.3. Delivery Count Persistence")  |  True means that the delivery count is persisted before delivery. False means that this only happens after a message has been cancelled. Default=false
-[persistence-enabled](persistence.md "15.6. Configuring ActiveMQ for Zero Persistence")               |  true means that the server will use the file based journal for persistence. Default=true
+[persistence-enabled](persistence.md "15.6. Configuring ActiveMQ Artemis for Zero Persistence")               |  true means that the server will use the file based journal for persistence. Default=true
 [persist-id-cache](duplicate-detection.md "37.2. Configuring the Duplicate ID Cache")                 |  true means that ID's are persisted to the journal. Default=true
 [queues](queue-attributes.md "25.1. Predefined Queues")       |  [a list of queue to be created](#queue-type)
 [remoting-incoming-interceptors](intercepting-operations.md "Chapter 47. Intercepting Operations")                                                   |  A list of interceptor
@@ -354,7 +354,7 @@ Apache ActiveMQ Artemis will load this property and initialize the class with a
 parameter map containing the "key"-\>"value" pair. If `passwordCodec` is
 not specified, the built-in decoder is used.
 
-### Masking passwords in ActiveMQ ResourceAdapters and MDB activation configurations
+### Masking passwords in ActiveMQ Artemis ResourceAdapters and MDB activation configurations
 
 Both ra.xml and MDB activation configuration have a 'password' property
 that can be masked. They are controlled by the following two optional
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQSession.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQSession.java
index 2bd5572..b46118d 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQSession.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQSession.java
@@ -61,7 +61,7 @@ import org.apache.activemq.artemis.api.core.client.ClientSession.AddressQuery;
 import org.apache.activemq.artemis.api.core.client.ClientSession.QueueQuery;
 
 /**
  * ActiveMQ implementation of a JMS Session.
  * <br>
  * Note that we *do not* support JMS ASF (Application Server Facilities) optional
  * constructs such as ConnectionConsumer
@@ -307,7 +307,7 @@ public class ActiveMQSession implements QueueSession, TopicSession
    {
       if (destination != null && !(destination instanceof ActiveMQDestination))
       {
-         throw new InvalidDestinationException("Not a ActiveMQ Destination:" + destination);
+         throw new InvalidDestinationException("Not a ActiveMQ Artemis Destination:" + destination);
       }
 
       try

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/jms/client/ActiveMQStreamMessage.java
----------------------------------------------------------------------
@@ -61,7 +61,7 @@ import org.apache.activemq.artemis.api.core.client.ClientSession.AddressQuery;
 
 /**
- * ActiveMQ implementation of a JMS Session.
+ * ActiveMQ Artemis implementation of a JMS Session.
  * <br>
  * Note that we *do not* support JMS ASF (Application Server Facilities) optional
diff --git a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireMessageConverter.java b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireMessageConverter.java
index 421b1a2..09af871 100644
--- a/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireMessageConverter.java
+++ b/artemis-protocols/artemis-openwire-protocol/src/main/java/org/apache/activemq/artemis/core/protocol/openwire/OpenWireMessageConverter.java
@@ -103,7 +103,7 @@ public class OpenWireMessageConverter implements MessageConverter
       return null;
    }
 
    //convert an ActiveMQ message to coreMessage
    public static void toCoreMessage(ServerMessageImpl coreMessage, Message messageSend, WireFormat marshaller) throws IOException
    {
       String type = messageSend.getType();
@@ -400,7 +400,7 @@ public class OpenWireMessageConverter implements MessageConverter
          case CommandTypes.ACTIVEMQ_MESSAGE:
             return org.apache.activemq.artemis.api.core.Message.DEFAULT_TYPE;
          default:
-            throw new IllegalStateException("Unknown ActiveMQ message type: " + amqType);
+            throw new IllegalStateException("Unknown ActiveMQ Artemis message type: " + amqType);
       }
    }
 

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/a17c828b/artemis-protocols/artemis-proton-plug/src/main/java/org/proton/plug/context/AbstractProtonContextSender.java
----------------------------------------------------------------------
@@ -103,7 +103,7 @@ public class OpenWireMessageConverter implements MessageConverter
    }
 
-   //convert an ActiveMQ message to coreMessage
+   //convert an ActiveMQ Artemis message to coreMessage
    public static void toCoreMessage(ServerMessageImpl coreMessage, Message messageSend, WireFormat marshaller) throws IOException
    {